@@ -5,7 +5,7 @@ author = {
 	"email":"maloja@krateng.dev",
 	"github": "krateng"
 }
-version = 2,5,0
+version = 2,6,4
 versionstr = ".".join(str(n) for n in version)
 links = {
 	"pypi":"malojaserver",
@@ -15,7 +15,7 @@ links = {
 requires = [
 	"bottle>=0.12.16",
 	"waitress>=1.3",
-	"doreah>=1.6.3",
+	"doreah>=1.6.7",
 	"nimrodel>=0.6.3",
 	"setproctitle>=1.1.10",
 	"wand>=0.5.4",
@@ -29,7 +29,10 @@ resources = [
 	"web/*",
 	"static/*/*",
 	"data_files/*/*",
-	"data_files/*/*/*"
+	"data_files/*/*/*",
+	"*/*.py",
+	"*/*/*.py",
+	"*/*/*/*.py"
 ]
 
 commands = {
